@@ -1,4 +1,6 @@
 /*
+ *  arch-tag: Header with definitions of various GConf keys
+ *
  *  Copyright (C) 2002 Jorn Baayen
  *  Copyright (C) 2003 Colin Walters <cwalters@gnome.org>
  *
@@ -16,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rb-preferences.h,v 1.4 2003/08/05 02:10:14 cwalters Exp $
  */
 
 #ifndef __RB_PREFERENCES_H
@@ -27,6 +28,11 @@ G_BEGIN_DECLS
 #define CONF_PREFIX "/apps/rhythmbox"
 
 #define CONF_FIRST_TIME CONF_PREFIX "/first_time_flag"
+#define CONF_UI_DIR               CONF_PREFIX "/ui"
+#define CONF_UI_STATUSBAR_HIDDEN  CONF_PREFIX "/ui/statusbar_hidden"
+#define CONF_UI_SOURCELIST_HIDDEN CONF_PREFIX "/ui/sourcelist_hidden"
+#define CONF_UI_SMALL_DISPLAY     CONF_PREFIX "/ui/small_display"
+#define CONF_UI_COLUMNS_SETUP CONF_PREFIX "/ui/columns_setup"
 #define CONF_UI_BROWSER_VIEWS CONF_PREFIX "/ui/browser_views"
 #define CONF_STATE_SHUFFLE	CONF_PREFIX "/state/shuffle"
 #define CONF_STATE_REPEAT	CONF_PREFIX "/state/repeat"
