@@ -1,4 +1,7 @@
 /*  monkey-media
+ *
+ *  arch-tag: Implementation of Xine audio backend
+ *
  *  Copyright (C) 2003 Jorn Baayen <jorn@nl.linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -15,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: monkey-media-player-xine.c,v 1.4 2003/08/26 23:12:03 hadess Exp $
  */
 
 #include <config.h>
@@ -520,8 +522,10 @@ monkey_media_player_pause (MonkeyMediaPlayer *mp)
 		if (xine_get_param (mp->priv->stream, XINE_PARAM_SPEED) == XINE_SPEED_NORMAL)
 			xine_set_param (mp->priv->stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE);
 
+#ifdef HAVE_XINE_CLOSE
 		/* Close the audio device when on pause */
 		xine_set_param (mp->priv->stream, XINE_PARAM_AUDIO_CLOSE_DEVICE, 1);
+#endif
 	}
 
 	mp->priv->timer_add += floor (g_timer_elapsed (mp->priv->timer, NULL) + 0.5);
