@@ -1,4 +1,6 @@
 /* 
+ *  arch-tag: Implementation of search entry/browse toggle container
+ *
  *  Copyright (C) 2003 Colin Walters <walters@debian.org>
  *  Copyright (C) 2003 Jorn Baayen <jorn@nl.linux.org>
  *
@@ -16,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rb-source-header.c,v 1.14 2003/08/19 00:10:42 cwalters Exp $
  */
 
 #include <gtk/gtk.h>
@@ -66,7 +67,6 @@ static void rb_source_header_view_browser_changed_cb (BonoboUIComponent *compone
 						      Bonobo_UIComponent_EventType type,
 						      const char *state,
 						      RBSourceHeader *header);
-static void rb_source_header_sync_control_state (RBSourceHeader *header);
 
 struct RBSourceHeaderPrivate
 {
@@ -373,15 +373,17 @@ rb_source_header_view_browser_changed_cb (BonoboUIComponent *component,
 			       rb_bonobo_get_active (component, CMD_PATH_VIEW_BROWSER));
 }
 
-static void
+void
 rb_source_header_sync_control_state (RBSourceHeader *header)
 {
 	gboolean have_browser = header->priv->selected_source != NULL
 		&& header->priv->browser_key != NULL;
+	gboolean not_small = !eel_gconf_get_boolean (CONF_UI_SMALL_DISPLAY);
+
 	gtk_widget_set_sensitive (header->priv->disclosure,
 				  have_browser);
 	rb_bonobo_set_sensitive (header->priv->component, CMD_PATH_VIEW_BROWSER,
-				have_browser);
+				have_browser && not_small);
 	if (have_browser) {
 		gboolean shown = eel_gconf_get_boolean (header->priv->browser_key);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (header->priv->disclosure),
