@@ -1,4 +1,6 @@
 /* 
+ *  arch-tag: Implementation of Internet Radio source object
+ *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2002,2003 Colin Walters <walters@debian.org>
  *
@@ -16,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rb-iradio-source.c,v 1.18 2003/08/17 07:34:19 cwalters Exp $
  */
 
 #include <config.h>
@@ -350,14 +351,12 @@ rb_iradio_source_get_property (GObject *object,
 }
 
 RBSource *
-rb_iradio_source_new (BonoboUIContainer *container,
-		    RBIRadioBackend *backend)
+rb_iradio_source_new (RBIRadioBackend *backend)
 {
 	RBSource *source;
 
 	source = RB_SOURCE (g_object_new (RB_TYPE_IRADIO_SOURCE,
 					  "name", _("Radio"),
-					  "container", container,
 					  "backend", backend,
 					  NULL));
 
