@@ -1,4 +1,6 @@
 /*
+ *  arch-tag: Implementation of local file source object
+ *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003 Colin Walters <walters@verbum.org>
  *
@@ -16,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rb-library-source.c,v 1.31 2003/08/19 21:56:07 cwalters Exp $
  */
 
 #include <config.h>
@@ -108,6 +109,7 @@ static void impl_song_properties (RBSource *source);
 static const char * impl_get_artist (RBSource *player);
 static const char * impl_get_album (RBSource *player);
 static gboolean impl_receive_drag (RBSource *source, GtkSelectionData *data);
+static gboolean impl_show_popup (RBSource *source);
 
 static void artists_filter (RBLibrarySource *source,
 	                    RBNode *genre);
@@ -124,6 +126,7 @@ void rb_library_source_browser_views_activated_cb (GtkWidget *widget,
 
 
 #define LIBRARY_SOURCE_SONGS_POPUP_PATH "/popups/LibrarySongsList"
+#define LIBRARY_SOURCE_POPUP_PATH "/popups/LibrarySourceList"
 
 #define CONF_UI_LIBRARY_DIR CONF_PREFIX "/ui/library"
 #define CONF_UI_LIBRARY_BROWSER_VIEWS CONF_PREFIX "/ui/library/browser_views"
@@ -242,6 +245,7 @@ rb_library_source_class_init (RBLibrarySourceClass *klass)
 	source_class->impl_get_album = impl_get_album;
 	source_class->impl_have_url = (RBSourceFeatureFunc) rb_false_function;
 	source_class->impl_receive_drag = impl_receive_drag;
+	source_class->impl_show_popup = impl_show_popup;
 
 	g_object_class_install_property (object_class,
 					 PROP_LIBRARY,
@@ -520,14 +524,12 @@ rb_library_source_get_property (GObject *object,
 }
 
 RBSource *
-rb_library_source_new (BonoboUIContainer *container,
-		       RBLibrary *library)
+rb_library_source_new (RBLibrary *library)
 {
 	RBSource *source;
 
 	source = RB_SOURCE (g_object_new (RB_TYPE_LIBRARY_SOURCE,
 					  "name", _("Library"),
-					  "container", container,
 					  "library", library,
 					  NULL));
 
@@ -969,6 +971,13 @@ impl_receive_drag (RBSource *asource, GtkSelectionData *data)
 	return TRUE;
 }
 
+static gboolean
+impl_show_popup (RBSource *source)
+{
+	rb_bonobo_show_popup (GTK_WIDGET (source), LIBRARY_SOURCE_POPUP_PATH);
+	return TRUE;
+}
+
 static void
 rb_library_source_drop_cb (GtkWidget *widget,
 			 GdkDragContext *context,
